"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var vercel_exports = {};
__export(vercel_exports, {
  genVercelEntry: () => genVercelEntry
});
module.exports = __toCommonJS(vercel_exports);
var import_utils = require("@modern-js/utils");
var import_utils2 = require("../utils");
function genVercelEntry({ config, plugins, appContext } = {}) {
  const defaultConfig = {
    server: {
      port: 8080
    },
    output: {
      path: "."
    }
  };
  return `

  const fs = require('node:fs/promises');
  const path = require('node:path');
  const { createProdServer } = require('@modern-js/prod-server');
  ${(0, import_utils2.genPluginImportsCode)(plugins || [])}

  if(!process.env.NODE_ENV){
    process.env.NODE_ENV = 'production';
  }

  let requestHandler = null;
  async function createHandler() {
    try {
      let routes = [];
      const routeFilepath = path.join(__dirname, "${import_utils.ROUTE_SPEC_FILE}");
      try {
        await fs.access(routeFilepath);
        const content = await fs.readFile(routeFilepath, "utf-8");
        const routeSpec = JSON.parse(content);
        routes = routeSpec.routes;
      } catch (error) {
        console.warn('route.json not found, continuing with empty routes.');
      }

      const prodServerOptions = {
        pwd: __dirname,
        routes,
        config: ${JSON.stringify(config || defaultConfig)},
        serverConfigFile: '${import_utils.DEFAULT_SERVER_CONFIG}',
        plugins: ${(0, import_utils2.getPluginsCode)(plugins || [])},
        appContext: ${appContext ? (0, import_utils2.severAppContextTemplate)(appContext) : "undefined"},
        disableCustomHook: true
      }

      const app = await createProdServer(prodServerOptions)

      requestHandler = app.getRequestListener();

      return requestHandler;
    } catch(error) {
      console.error(error);
      process.exit(1);
    }
  }

  createHandler();

  module.exports = async(req, res) => {
    if(typeof requestHandler !== 'function'){
      await createHandler();
    }
    return requestHandler(req, res);
  }
  `;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  genVercelEntry
});
