"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var deploy_exports = {};
__export(deploy_exports, {
  default: () => deploy_default
});
module.exports = __toCommonJS(deploy_exports);
var import_path = __toESM(require("path"));
var import_utils = require("@modern-js/utils");
var import_utils2 = require("./utils");
var import_dependencies = require("./dependencies");
var deploy_default = () => ({
  name: "@modern-js/plugin-deploy",
  pre: [
    "@modern-js/plugin-bff",
    "@modern-js/plugin-server"
  ],
  setup: (api) => {
    const deployTarget = process.env.MODERNJS_DEPLOY || "node";
    return {
      async beforeDeploy() {
        const appContext = api.useAppContext();
        const { appDirectory, distDirectory, serverInternalPlugins, sharedDirectory, apiDirectory, lambdaDirectory, metaName } = appContext;
        const { useSSR, useAPI, useWebServer } = (0, import_utils2.getProjectUsage)(appDirectory, distDirectory);
        const needModernServer = useSSR || useAPI || useWebServer;
        const configContext = api.useResolvedConfigContext();
        let outputDirectory = import_path.default.join(appDirectory, ".output");
        let funcsDirectory = outputDirectory;
        let staticDirectory = import_path.default.join(outputDirectory, "static");
        if (deployTarget === "node") {
          await import_utils.fs.remove(outputDirectory);
          await import_utils.fs.copy(distDirectory, outputDirectory);
        }
        if (deployTarget === "vercel") {
          const vercelOutput = import_path.default.join(appDirectory, ".vercel");
          await import_utils.fs.remove(vercelOutput);
          outputDirectory = import_path.default.join(vercelOutput, "output");
          const config2 = {
            version: 3,
            routes: [
              {
                src: "/static/(.*)",
                headers: {
                  "cache-control": "s-maxage=31536000, immutable"
                },
                continue: true
              },
              {
                handle: "filesystem"
              },
              {
                src: "/(.*)",
                headers: {
                  "cache-control": "s-maxage=0"
                },
                dest: "/html/main/index.html"
              }
            ]
          };
          await import_utils.fs.ensureDir(outputDirectory);
          await import_utils.fs.writeJSON(import_path.default.join(outputDirectory, "config.json"), config2);
          staticDirectory = import_path.default.join(outputDirectory, "static/static");
          await import_utils.fs.copy(import_path.default.join(distDirectory, "static"), staticDirectory);
          if (!needModernServer) {
            const destHtmlDirectory = import_path.default.join(distDirectory, "html");
            const outputHtmlDirectory = import_path.default.join(import_path.default.join(outputDirectory, "static"), "html");
            await import_utils.fs.copy(destHtmlDirectory, outputHtmlDirectory);
          } else {
            funcsDirectory = import_path.default.join(outputDirectory, "functions", "index.func");
            await import_utils.fs.ensureDir(funcsDirectory);
            await import_utils.fs.copy(distDirectory, funcsDirectory, {
              filter: (src) => {
                const distStaticDirectory = import_path.default.join(distDirectory, "static");
                return !src.includes(distStaticDirectory);
              }
            });
            await import_utils.fs.writeJSON(import_path.default.join(funcsDirectory, ".vc-config.json"), {
              runtime: "nodejs16.x",
              handler: "index.js",
              launcherType: "Nodejs",
              shouldAddHelpers: false,
              supportsResponseStreaming: true
            });
          }
        }
        const { bff } = configContext;
        const config = {
          output: {
            path: "."
          },
          bff
        };
        const plugins = (0, import_utils.getInternalPlugins)(appDirectory, serverInternalPlugins);
        const serverAppContext = {
          sharedDirectory: `path.join(__dirname, "${import_path.default.relative(appDirectory, sharedDirectory)}")`,
          apiDirectory: `path.join(__dirname, "${import_path.default.relative(appDirectory, apiDirectory)}")`,
          lambdaDirectory: `path.join(__dirname, "${import_path.default.relative(appDirectory, lambdaDirectory)}")`,
          metaName
        };
        let code = ``;
        console.log("deployTarget111111111", deployTarget);
        switch (deployTarget) {
          case "node": {
            const { genNodeEntry } = await Promise.resolve().then(() => __toESM(require("./entrys/node")));
            code = genNodeEntry({
              plugins,
              config,
              appContext: serverAppContext
            });
            break;
          }
          case "vercel": {
            const { genVercelEntry } = await Promise.resolve().then(() => __toESM(require("./entrys/vercel")));
            code = genVercelEntry({
              plugins,
              config,
              appContext: serverAppContext
            });
            break;
          }
          case "netlify": {
            const { genNetlifyEntry } = await Promise.resolve().then(() => __toESM(require("./entrys/netlify")));
            code = genNetlifyEntry({
              plugins,
              config,
              appContext: serverAppContext
            });
            break;
          }
          default: {
            code = `throw new Error("unknown deploy target, MODERNJS_DEPLOY should be set");`;
          }
        }
        const entryFilePath = import_path.default.join(funcsDirectory, "index.js");
        if (needModernServer) {
          await import_utils.fs.writeFile(entryFilePath, code);
          await (0, import_dependencies.handleDependencies)(appDirectory, funcsDirectory, [
            "@modern-js/prod-server"
          ]);
        }
      }
    };
  }
});
